==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebToggleViewEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToggleViewEventArgsDetailDescriptionMetadata } from "./WebToggleViewEventArgsDetailDescriptionMetadata";
import { WebToggleViewEventArgsDescription } from "./WebToggleViewEventArgsDescription";
/**
 * @hidden
 */
export let WebToggleViewEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebToggleViewEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebToggleViewEventArgsDescriptionMetadata.a == null) {
                WebToggleViewEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebToggleViewEventArgsDescriptionMetadata.c(WebToggleViewEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebToggleViewEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebToggleViewEventArgsDescriptionMetadata.a);
            WebToggleViewEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ToggleViewEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebToggleViewEventArgsDetail");
        }
        static d(a) {
            WebToggleViewEventArgsDescriptionMetadata.b(a);
            a.ad("WebToggleViewEventArgs", () => new WebToggleViewEventArgsDescription());
            a.ac("WebToggleViewEventArgs", WebToggleViewEventArgsDescriptionMetadata.a);
        }
    }
    WebToggleViewEventArgsDescriptionMetadata.$t = markType(WebToggleViewEventArgsDescriptionMetadata, 'WebToggleViewEventArgsDescriptionMetadata');
    WebToggleViewEventArgsDescriptionMetadata.a = null;
    return WebToggleViewEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebToggleViewEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebToggleViewEventArgsDetailDescriptionMetadata } from "./WebToggleViewEventArgsDetailDescriptionMetadata";
import { WebToggleViewEventArgsDescription } from "./WebToggleViewEventArgsDescription";
/**
 * @hidden
 */
export let WebToggleViewEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebToggleViewEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebToggleViewEventArgsDescriptionMetadata.a == null) {
                WebToggleViewEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebToggleViewEventArgsDescriptionMetadata.c(WebToggleViewEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebToggleViewEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebToggleViewEventArgsDescriptionMetadata.a);
            WebToggleViewEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ToggleViewEventArgs");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__marshalByValue", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebToggleViewEventArgsDetail");
        }
        static d(a) {
            WebToggleViewEventArgsDescriptionMetadata.b(a);
            a.ae("WebToggleViewEventArgs", () => new WebToggleViewEventArgsDescription());
            a.ad("WebToggleViewEventArgs", WebToggleViewEventArgsDescriptionMetadata.a);
        }
    }
    WebToggleViewEventArgsDescriptionMetadata.$t = markType(WebToggleViewEventArgsDescriptionMetadata, 'WebToggleViewEventArgsDescriptionMetadata');
    WebToggleViewEventArgsDescriptionMetadata.a = null;
    return WebToggleViewEventArgsDescriptionMetadata;
})();
